
//***********************************************************************
//***********************************************************************
//                      MARLIN CLONEBOT FIRMWARE
//
//  Autor: Adrian Moreno Pina
//  Fecha: 31/10/2014
//  Version: V1.0.0
//  Maquina Reprap: CloneBot I3
//
//***********************************************************************
//***********************************************************************

#ifndef CONFIGURATION_H
#define CONFIGURATION_H

//FIRMWARE CLONEBOT 3D PRINTERS
  #define STRING_VERSION_CONFIG_H __DATE__ " " __TIME__ // build date and time
  #define STRING_CONFIG_H_AUTHOR "(CloneBot 3D Printers FW v1.0.0)" // Who made the changes.

//CONFIGURACION PUERTO SERIAL
  #define SERIAL_PORT 0
  #define BAUDRATE 115200

//NOMBRE DE LA IMPRESORA
  #define MACHINE_NAME "CloneBot II"
  #define FIRMWARE_URL "www.clonebot3dprinters@gmail.com"
  #define FIRMWARE_VER "v1.0.0"
  
//NUMERO DE SERIE
  #define MACHINE_UUID "00000000-0000-0000-0000-000000000000"

//SELECCION ELECTRONICA
  // 33 = RAMPS 1.3 / 1.4 (Power outputs: Extruder, Fan, Bed)
  // 34 = RAMPS 1.3 / 1.4 (Power outputs: Extruder0, Extruder1, Bed)
  // 35 = RAMPS 1.3 / 1.4 (Power outputs: Extruder, Fan, Fan)
  // 36 = RAMPS 1.3 / 1.4 (Power outputs: Extruder0, Fan, Extruder1)
  #define MOTHERBOARD 34

//Numero de Extrusores
  #define EXTRUDERS 1

//Seleccion Fuente de Alimentacion
  #define POWER_SUPPLY 1

//Control de Fuente de Alimentacion
  #define PS_DEFAULT_OFF

// SELECCION DEL TERMISTOR
  // 0 is not used
  // 1 is 100k thermistor - best choice for EPCOS 100k (4.7k pullup)
  // 7 is 100k Honeywell thermistor 135-104LAG-J01 (4.7k pullup)
  #define TEMP_SENSOR_0 1
  #define TEMP_SENSOR_1 0
  #define TEMP_SENSOR_2 0
  #define TEMP_SENSOR_BED 1

//DIFERENCIA ENTRE LOS TERMISTORES
  //#define TEMP_SENSOR_1_AS_REDUNDANT
  #define MAX_REDUNDANT_TEMP_SENSOR_DIFF 10

//CONFIGURACION LECTURA TEMPERATURA
  #define TEMP_RESIDENCY_TIME 10  // (seconds)
  #define TEMP_HYSTERESIS 3       // (degC) range of +/- temperatures considered "close" to the target one
  #define TEMP_WINDOW     1       // (degC) Window around target to start the residency timer x degC early.

//MINIMA TEMPERATURA TERMISTOR
  #define HEATER_0_MINTEMP 5
  #define HEATER_1_MINTEMP 5
  #define HEATER_2_MINTEMP 5
  #define BED_MINTEMP 5

//MAXIMA TEMPERATURA TERMISTOR
  #define HEATER_0_MAXTEMP 260
  #define HEATER_1_MAXTEMP 260
  #define HEATER_2_MAXTEMP 260
  #define BED_MAXTEMP 150

//PID EXTRUSOR
  #define PIDTEMP
  //EJECUTAR: "M303 E0 C8 S230"
  #define BANG_MAX 255 // limits current to nozzle while in bang-bang mode; 255=full current
  #define PID_MAX 255 // limits current to nozzle while PID is active (see PID_FUNCTIONAL_RANGE below); 255=full current
  #ifdef PIDTEMP
    #define PID_FUNCTIONAL_RANGE 10 
    #define PID_INTEGRAL_DRIVE_MAX 255  //limit for the integral term
    #define K1 0.95 //smoothing factor within the PID
    #define PID_dT ((OVERSAMPLENR * 8.0)/(F_CPU / 64.0 / 256.0)) //sampling period of the temperature routine
    //PID HOTEND Clonebot_I3
        #define  DEFAULT_Kp 23.05
        #define  DEFAULT_Ki 2.00  
        #define  DEFAULT_Kd 66.47  
  #endif 

//PID HOTBED
  #define PIDTEMPBED
  //#define BED_LIMIT_SWITCHING
  #define MAX_BED_POWER 255 // limits duty cycle to bed; 255=full current
  
  #ifdef PIDTEMPBED
  //EJECUTAR: "M303 E-1 C8 S90"
  //PID HOTBED CloneBot I3
      #define  DEFAULT_bedKp 10.00
      #define  DEFAULT_bedKi .023
      #define  DEFAULT_bedKd 305.4
  #endif

//MINIMA TEMPERATURA EXTRUSION
  #define PREVENT_DANGEROUS_EXTRUDE
  #define PREVENT_LENGTHY_EXTRUDE
  #define EXTRUDE_MINTEMP 20
  #define EXTRUDE_MAXLENGTH (X_MAX_LENGTH+Y_MAX_LENGTH) //prevent extrusion of very large distances.

//===========================================================================
//=============================Mechanical Settings===========================
//===========================================================================

// ACTIVACION CINEMATICA CORE XY
  // #define COREXY

// CONFIGURACION ENDSTOP
  #define ENDSTOPPULLUPS 
  #ifndef ENDSTOPPULLUPS
    #define ENDSTOPPULLUP_XMAX
    #define ENDSTOPPULLUP_YMAX
    #define ENDSTOPPULLUP_ZMAX
    #define ENDSTOPPULLUP_XMIN
    #define ENDSTOPPULLUP_YMIN
    #define ENDSTOPPULLUP_ZMIN
  #endif
  #ifdef ENDSTOPPULLUPS
    #define ENDSTOPPULLUP_XMAX
    #define ENDSTOPPULLUP_YMAX
    #define ENDSTOPPULLUP_ZMAX
    #define ENDSTOPPULLUP_XMIN
    #define ENDSTOPPULLUP_YMIN
    #define ENDSTOPPULLUP_ZMIN
  #endif

//CONFIGURACION SE�ALES ENDSTOP
  const bool X_MIN_ENDSTOP_INVERTING = true; // set to true to invert the logic of the endstop.
  const bool Y_MIN_ENDSTOP_INVERTING = true; // set to true to invert the logic of the endstop.
  const bool Z_MIN_ENDSTOP_INVERTING = true; // set to true to invert the logic of the endstop.
  const bool X_MAX_ENDSTOP_INVERTING = true; // set to true to invert the logic of the endstop.
  const bool Y_MAX_ENDSTOP_INVERTING = true; // set to true to invert the logic of the endstop.
  const bool Z_MAX_ENDSTOP_INVERTING = true; // set to true to invert the logic of the endstop.

// CONFIGURACION MOVIMIENTOS
  //(Active Low) use 0,(Active High) use 1
  #define X_ENABLE_ON 0
  #define Y_ENABLE_ON 0
  #define Z_ENABLE_ON 0
  #define E_ENABLE_ON 0 
  
  //Desactivar el eje cuando no se utiliza
  #define DISABLE_X false
  #define DISABLE_Y false
  #define DISABLE_Z true
  #define DISABLE_E false 
  
  //Configuracion sentido giro del motor
  #define INVERT_X_DIR false    
  #define INVERT_Y_DIR false   
  #define INVERT_Z_DIR false   
  #define INVERT_E0_DIR true  
  #define INVERT_E1_DIR false    
  #define INVERT_E2_DIR false   

//CONFIGURACION PROCESO DE CALIBRACION	
  //1=MAX, -1=MIN
  #define X_HOME_DIR -1
  #define Y_HOME_DIR -1
  #define Z_HOME_DIR -1
  
  #define min_software_endstops true // If true, axis won't move to coordinates less than HOME_POS.
  #define max_software_endstops true  // If true, axis won't move to coordinates greater than the defined lengths below.

//CONFIGURACION CARRERAS MAQUINA
  #define X_MAX_POS 300
  #define X_MIN_POS 0
  #define Y_MAX_POS 300
  #define Y_MIN_POS 0
  #define Z_MAX_POS 180
  #define Z_MIN_POS 0
  
  #define X_MAX_LENGTH (X_MAX_POS - X_MIN_POS)
  #define Y_MAX_LENGTH (Y_MAX_POS - Y_MIN_POS)
  #define Z_MAX_LENGTH (Z_MAX_POS - Z_MIN_POS)


//AUTONIVELACION DE LA CAMA
  //#define ENABLE_AUTO_BED_LEVELING // Delete the comment to enable (remove // at the start of the line)
  #ifdef ENABLE_AUTO_BED_LEVELING
    #define AUTO_BED_LEVELING_GRID
    #ifdef AUTO_BED_LEVELING_GRID
      // set the rectangle in which to probe
      #define LEFT_PROBE_BED_POSITION 15
      #define RIGHT_PROBE_BED_POSITION 170
      #define BACK_PROBE_BED_POSITION 180
      #define FRONT_PROBE_BED_POSITION 20
      #define AUTO_BED_LEVELING_GRID_POINTS 2
    #else  // not AUTO_BED_LEVELING_GRID
        #define ABL_PROBE_PT_1_X 15
        #define ABL_PROBE_PT_1_Y 180
        #define ABL_PROBE_PT_2_X 15
        #define ABL_PROBE_PT_2_Y 20
        #define ABL_PROBE_PT_3_X 170
        #define ABL_PROBE_PT_3_Y 20
    #endif // AUTO_BED_LEVELING_GRID
    // these are the offsets to the probe relative to the extruder tip (Hotend - Probe)
    #define X_PROBE_OFFSET_FROM_EXTRUDER -25
    #define Y_PROBE_OFFSET_FROM_EXTRUDER -29
    #define Z_PROBE_OFFSET_FROM_EXTRUDER -12.35
    #define Z_RAISE_BEFORE_HOMING 4       // (in mm) Raise Z before homing (G28) for Probe Clearance.
    #define Z_RAISE_BEFORE_PROBING 15    //How much the extruder will be raised before traveling to the first probing point.
    #define Z_RAISE_BETWEEN_PROBINGS 5  //How much the extruder will be raised when traveling from between next probing points
    //#define PROBE_SERVO_DEACTIVATION_DELAY 300
    #define Z_SAFE_HOMING   // This feature is meant to avoid Z homing with probe outside the bed area.
    #ifdef Z_SAFE_HOMING
      #define Z_SAFE_HOMING_X_POINT (X_MAX_LENGTH/2)    // X point for Z homing when homing all axis (G28)
      #define Z_SAFE_HOMING_Y_POINT (Y_MAX_LENGTH/2)    // Y point for Z homing when homing all axis (G28)
    #endif
  #endif // ENABLE_AUTO_BED_LEVELING

  // The position of the homing switches
  //#define MANUAL_HOME_POSITIONS  // If defined, MANUAL_*_HOME_POS below will be used
  //#define BED_CENTER_AT_0_0  // If defined, the center of the bed is at (X=0, Y=0)
  
  //Manual homing switch locations:
  #define MANUAL_X_HOME_POS 0
  #define MANUAL_Y_HOME_POS 0
  #define MANUAL_Z_HOME_POS 0
  //#define MANUAL_Z_HOME_POS 402 // For delta: Distance between nozzle and print surface after homing.


//CONFIGURACION MOVIMIENTOS
  #define NUM_AXIS 4 // The axis order in all axis related arrays is X, Y, Z, E
  
  //Velocidades y Aceleraciones
    #define HOMING_FEEDRATE 			  {2000, 2000, 150, 0}  //{50*60, 50*60, 4*60, 0} set the homing speeds (mm/min)
    #define DEFAULT_AXIS_STEPS_PER_UNIT   {81.3421, 80.7265, 2556.8039,96.84}  // default steps per unit for Ultimaker
    #define DEFAULT_MAX_FEEDRATE          {200, 200, 2.9, 25}    // (mm/sec)
    #define DEFAULT_MAX_ACCELERATION      {1000,1000,5,1000}    // X, Y, Z, E maximum start speed for accelerated moves. E default values are good for Skeinforge 40+, for older versions raise them a lot.
    
    #define DEFAULT_ACCELERATION          500    // X, Y, Z and E max acceleration in mm/s^2 for printing moves
    #define DEFAULT_RETRACT_ACCELERATION  1000   // X, Y, Z and E max acceleration in mm/s^2 for retracts
  
  // Offset of the extruders (uncomment if using more than one and relying on firmware to position when changing).
    // #define EXTRUDER_OFFSET_X {0.0, 20.00} // (in mm) for each extruder, offset of the hotend on the X axis
    // #define EXTRUDER_OFFSET_Y {0.0, 5.00}  // (in mm) for each extruder, offset of the hotend on the Y axis
  
  // The speed change that does not require acceleration (i.e. the software might assume it can be done instantaneously)
    #define DEFAULT_XYJERK                10.0    // (mm/sec)
    #define DEFAULT_ZJERK                 0.4     // (mm/sec)
    #define DEFAULT_EJERK                 5.0    // (mm/sec)


//===================================================================================================================
//=============================CONFIGURACION IMPRESORA CLONEBOT======================================================
//===================================================================================================================

   #define CLONEBOT          //Impresora CloneBot
  //#define CLONEBOT_DUAL    //Si se activa, Impresora CloneBot de 2 extrusor
  
  //Configuracion Puntos Nivelacion Cama
    #ifdef CLONEBOT
      #define Punto_1_X  10  
      #define Punto_1_Y  0
     
      #define Punto_2_X  200  
      #define Punto_2_Y  0
     
      #define Punto_3_X  200
      #define Punto_3_Y  200
     
      #define Punto_4_X  10
      #define Punto_4_Y  200
     
      #define Punto_5_X  100
      #define Punto_5_Y  100
     
      #define Punto_6_X  0
      #define Punto_6_Y  0
    #endif
  
  #ifdef CLONEBOT
  	#define EXTRUSION_SPEED 300
  	#define LEVEL_PLATE_TEMP_PROTECTION 60
  	#define Change_Filament_Target_Temp 220
 
  	#define FILAMENT_EXTRUSION_LENGTH 100
  	#define FILAMENT_UNLOAD_EXTRUSION_LENGTH 5
  	#define FILAMENT_UNLOAD_RETRACTION_LENGTH 100
         
        #define PLA_PREHEAT_HOTEND_TEMP 200
        #define PLA_PREHEAT_HPB_TEMP 0
        #define ABS_PREHEAT_HOTEND_TEMP 220
        #define ABS_PREHEAT_HPB_TEMP 100   
          
        #define PLA_PREHEAT_FAN_SPEED  125
        #define ABS_PREHEAT_FAN_SPEED  125
  	#define PREHEAT_FAN_SPEED 125     
        #define COOLDOWN_FAN_SPEED 255
  #endif
  
  #if defined(ENABLE_AUTO_BED_LEVELING) || defined(CLONEBOT)
    #define XY_TRAVEL_SPEED 8000 // X and Y axis travel speed between probes and Witbox movements, in mm/min
  #endif

//===================================================================================================================
//=============================CONFIGURACIONES ADICIONALES===========================================================
//===================================================================================================================

  //ACTIVACION DE EEPROM
    #define EEPROM_SETTINGS
    #define EEPROM_CHITCHAT
  
  // CONFIGURACION LCD
    #define ULTIPANEL  //the UltiPanel as on Thingiverse
    #ifdef ULTIPANEL
      #define NEWPANEL  
      #define SDSUPPORT
      #define ULTRA_LCD
      #define LCD_WIDTH 20
      #define LCD_HEIGHT 4
    #else 
      #ifdef ULTRA_LCD
        #define LCD_WIDTH 16
        #define LCD_HEIGHT 2
      #endif
    #endif
  
  //CONFIGURACION SALIDA PWM
    #define SOFT_PWM_SCALE 0
 
  //CONFIGURACION SERVOS
  #define NUM_SERVOS 3 // Servo index starts with 0 for M280 command
    //#define SERVO_ENDSTOPS {-1, -1, 0} // Servo index for X, Y, Z. Disable with -1
  #define SERVO_ENDSTOP_ANGLES {0,0, 0,0, 70,0} // X,Y,Z Axis Extend and Retract angles

#include "Configuration_adv.h"
#include "thermistortables.h"

#endif //__CONFIGURATION_H
